.. currentmodule:: sardana.tango.macroserver.test.macroexecutor

:mod:`~sardana.tango.macroserver.test.macroexecutor`
====================================================

.. automodule:: sardana.tango.macroserver.test.macroexecutor

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`BaseMacroExecutor`
    * :class:`MacroExecutorFactory`


TangoAttrCb
-----------

.. inheritance-diagram:: TangoAttrCb
    :parts: 1

.. autoclass:: TangoAttrCb
    :members:
    :undoc-members:


TangoResultCb
-------------

.. inheritance-diagram:: TangoResultCb
    :parts: 1

.. autoclass:: TangoResultCb
    :inherited-members:
    :members:
    :undoc-members:


TangoLogCb
----------

.. inheritance-diagram:: TangoLogCb
    :parts: 1

.. autoclass:: TangoLogCb
    :inherited-members:
    :members:
    :undoc-members:


TangoStatusCb
-------------

.. inheritance-diagram:: TangoStatusCb
    :parts: 1

.. autoclass:: TangoStatusCb
    :inherited-members:
    :members:
    :undoc-members:


TangoMacroExecutor
------------------

.. inheritance-diagram:: TangoMacroExecutor
    :parts: 1

.. autoclass:: TangoMacroExecutor
    :inherited-members:
    :members:
    :undoc-members:
